@@ -34,7 +34,6 @@ import (
 
 // TestDuplicatePodTaskRun creates 10 builds and checks that each of them has only one build pod.
 func TestDuplicatePodTaskRun(t *testing.T) {
-	t.Skip("Too much memory used on OpenShift")
 	t.Parallel()
 
 	ctx, cancel := context.WithCancel(context.Background())
@@ -55,7 +54,7 @@ func TestDuplicatePodTaskRun(t *testing.T) {
 			Spec: v1beta1.TaskRunSpec{
 				TaskSpec: &v1beta1.TaskSpec{
 					Steps: []v1beta1.Step{{Container: corev1.Container{
-						Image:   "mirror.gcr.io/library/busybox",
+						Image:   "busybox",
 						Command: []string{"/bin/echo"},
 						Args:    []string{"simple"},
 					}}},
@@ -74,7 +73,7 @@ func TestDuplicatePodTaskRun(t *testing.T) {
 			}
 
 			pods, err := c.KubeClient.CoreV1().Pods(namespace).List(ctx, metav1.ListOptions{
-				LabelSelector: fmt.Sprintf("%s=%s", pipeline.GroupName+pipeline.TaskRunLabelKey, taskrunName),
+				LabelSelector: fmt.Sprintf("%s=%s", pipeline.TaskRunLabelKey, taskrunName),
 			})
 			if err != nil {
 				t.Errorf("Error getting TaskRun pod list: %v", err)
